@@ -37,6 +37,7 @@ Copyright (c) Intel Corporation (2009-2017).
 #include "llvm/Support/Casting.h"
 #include "llvm/Support/Path.h"
 #include "llvm/Support/Threading.h"
+#include "llvm/Support/TargetSelect.h"
 #include "llvm/Support/ManagedStatic.h"
 #include "llvm/Support/Mutex.h"
 #include "clang/Basic/LangOptions.h"
@@ -58,7 +59,6 @@ Copyright (c) Intel Corporation (2009-2017).
 // in https://github.com/KhronosGroup/OpenCL-Headers/blob/master/CL/cl.h
 #define CL_SUCCESS 0
 #define CL_COMPILE_PROGRAM_FAILURE -15
-#define CL_INVALID_BUILD_OPTIONS -43
 #define CL_OUT_OF_HOST_MEMORY -6
 
 #include "assert.h"
@@ -77,7 +77,11 @@ Copyright (c) Intel Corporation (2009-2017).
 
 using namespace Intel::OpenCL::ClangFE;
 
-llvm::ManagedStatic<llvm::sys::SmartMutex<true>> compileMutex;
+static volatile bool lazyCCInit =
+    true; // the flag must be 'volatile' to prevent caching in a CPU register
+static llvm::sys::Mutex lazyCCInitMutex;
+
+static llvm::ManagedStatic<llvm::sys::SmartMutex<true> > compileMutex;
 
 void CommonClangTerminate() { llvm::llvm_shutdown(); }
 
@@ -85,13 +89,23 @@ void CommonClangTerminate() { llvm::llvm_shutdown(); }
 // from a DllMain function (Windows specific), or from a function
 // w\ __attribute__ ((constructor)) (Linux specific).
 void CommonClangInitialize() {
-  // CommonClangTerminate calls llvm_shutdown to deallocate resources used
-  // by LLVM libraries. llvm_shutdown uses static mutex to make it safe for
-  // multi-threaded envirounment and LLVM libraries user is expected call
-  // llvm_shutdown before static object are destroyed, so we use atexit to
-  // satisfy this requirement.
-  llvm::once_flag OnceFlag;
-  llvm::call_once(OnceFlag, []() { atexit(CommonClangTerminate); });
+  if (lazyCCInit) {
+    llvm::sys::ScopedLock lock(lazyCCInitMutex);
+
+    if (lazyCCInit) {
+      // CommonClangTerminate calls llvm_shutdown to deallocate resources used
+      // by LLVM libraries. llvm_shutdown uses static mutex to make it safe for
+      // multi-threaded envirounment and LLVM libraries user is expected call
+      // llvm_shutdown before static object are destroyed, so we use atexit to
+      // satisfy this requirement.
+      atexit(CommonClangTerminate);
+      llvm::InitializeAllTargets();
+      llvm::InitializeAllAsmPrinters();
+      llvm::InitializeAllAsmParsers();
+      llvm::InitializeAllTargetMCs();
+      lazyCCInit = false;
+    }
+  }
 }
 
 static bool GetHeaders(std::vector<Resource> &Result) {
@@ -194,9 +208,6 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
   CommonClangInitialize();
 
   try {
-#ifdef _WIN32
-    llvm::sys::SmartScopedLock<true> compileGuard{*compileMutex};
-#endif
     std::unique_ptr<OCLFEBinaryResult> pResult(new OCLFEBinaryResult());
 
     // Create the clang compiler
@@ -208,15 +219,10 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
     // Prepare error log
     llvm::raw_string_ostream err_ostream(pResult->getLogRef());
     {
-#ifndef _WIN32
-      llvm::sys::SmartScopedLock<true> compileGuard{*compileMutex};
-#endif
+      llvm::sys::SmartScopedLock<true> compileGuard {*compileMutex};
+
       // Parse options
-      if (optionsParser.processOptions(pszOptions, pszOptionsEx) != 0) {
-        if (pBinaryResult)
-          *pBinaryResult = nullptr;
-        return CL_INVALID_BUILD_OPTIONS;
-      }
+      optionsParser.processOptions(pszOptions, pszOptionsEx);
 
       // Prepare our diagnostic client.
       llvm::IntrusiveRefCntPtr<clang::DiagnosticIDs> DiagID(
@@ -304,7 +310,6 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
           pResult->GetIRSize());
       std::unique_ptr<llvm::MemoryBuffer> MB = llvm::MemoryBuffer::getMemBuffer(LLVM_IR, pResult->GetIRName(), false);
       llvm::LLVMContext Context;
-      Context.setOpaquePointers(optionsParser.hasOpaquePointers());
       auto E = llvm::getOwningLazyBitcodeModule(std::move(MB), Context,
           /*ShouldLazyLoadMetadata=*/true);
       llvm::logAllUnhandledErrors(E.takeError(), err_ostream, "error: ");
@@ -321,10 +326,8 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
       SmallVectorBuffer StreamBuf(pResult->getIRBufferRef());
       std::ostream OS(&StreamBuf);
       std::string Err;
-      SPIRV::TranslatorOpts SPIRVOpts(SPIRV::VersionNumber::MaximumVersion,
-                                      optionsParser.getSPIRVExtStatusMap());
-      if (!optionsParser.hasSPIRVExt())
-        SPIRVOpts.enableAllExtensions();
+      SPIRV::TranslatorOpts SPIRVOpts;
+      SPIRVOpts.enableAllExtensions();
       if (!optionsParser.hasOptDisable()) {
         SPIRVOpts.setMemToRegEnabled(true);
       }
@@ -334,9 +337,7 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
       err_ostream.flush();
     }
     {
-#ifndef _WIN32
-      llvm::sys::SmartScopedLock<true> compileGuard{*compileMutex};
-#endif
+      llvm::sys::SmartScopedLock<true> compileGuard {*compileMutex};
       if (pBinaryResult) {
         *pBinaryResult = pResult.release();
       }
